@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: imp/compose.php,v 2.800.2.130 2009/12/16 21:56:13 jan Exp $
+ * $Horde: imp/compose.php,v 2.800.2.131 2012/02/06 05:53:37 slusarz Exp $
  *
  * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
@@ -191,7 +191,8 @@ if ($browser->hasFeature('rte')) {
         if (is_null($rtemode)) {
             $rtemode = $prefs->getValue('compose_html');
         } else {
-            $oldrtemode = Util::getFormData('oldrtemode');
+            $rtemode = intval($rtemode);
+            $oldrtemode = intval(Util::getFormData('oldrtemode'));
             $get_sig = false;
         }
     }
@@ -226,8 +227,8 @@ if ($_SESSION['imp']['file_upload']) {
     /* Update the attachment information. */
     foreach (array_keys($imp_compose->getAttachments()) as $i) {
         if (!in_array($i, $deleteList)) {
-            $disposition = Util::getFormData('file_disposition_' . $i);
-            $description = Util::getFormData('file_description_' . $i);
+            $disposition = htmlspecialchars(Util::getFormData('file_disposition_' . $i));
+            $description = htmlspecialchars(Util::getFormData('file_description_' . $i));
             $imp_compose->updateAttachment($i, array('disposition' => $disposition, 'description' => $description));
         }
     }
@@ -1131,7 +1132,7 @@ if ($redirect) {
             $t->set('ssm_folders', IMP::flistSelect('', false, array('INBOX'), $sent_mail_folder));
         } else {
             if (!empty($sent_mail_folder)) {
-                $sent_mail_folder = '&quot;' . IMP::displayFolder($sent_mail_folder) . '&quot;';
+                $sent_mail_folder = '&quot;' . htmlspecialchars(IMP::displayFolder($sent_mail_folder)) . '&quot;';
             }
             $t->set('ssm_folder', $sent_mail_folder);
             $t->set('ssm_folders', false);
