@@ -3,7 +3,7 @@
 $block_name = _("Folder Summary");
 
 /**
- * $Horde: imp/lib/Block/summary.php,v 1.54.2.11 2007-12-20 13:59:25 jan Exp $
+ * $Horde: imp/lib/Block/summary.php,v 1.54.2.12 2012/02/06 05:53:38 slusarz Exp $
  *
  * @package Horde_Block
  */
@@ -81,7 +81,7 @@ class Horde_Block_imp_summary extends Horde_Block {
                             $html .= '<strong>';
                             $anyUnseen = true;
                         }
-                        $html .= Horde::link($url) . IMP::displayFolder($folder) . '</a>';
+                        $html .= Horde::link($url) . htmlspecialchars(IMP::displayFolder($folder)) . '</a>';
                         if (!empty($info['unseen'])) {
                             $html .= '</strong>';
                         }
