@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: imp/lib/Maintenance/Task/purge_sentmail.php,v 1.9.2.3 2009-01-06 15:24:10 jan Exp $
+ * $Horde: imp/lib/Maintenance/Task/purge_sentmail.php,v 1.9.2.4 2012/02/06 05:53:38 slusarz Exp $
  *
  * Maintenance module that purges old messages in the sent-mail folder.
  *
@@ -80,7 +80,7 @@ class Maintenance_Task_purge_sentmail extends Maintenance_Task {
                                  Maintenance_Task_purge_sentmail::_getFolders());
 
         return sprintf(_("All messages in the folder(s) \"%s\" older than %s days will be permanently deleted."),
-                       implode(', ', $folder_list),
+                       htmlspecialchars(implode(', ', $folder_list)),
                        $GLOBALS['prefs']->getValue('purge_sentmail_keep'));
     }
 
