@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: imp/lib/Maintenance/Task/purge_trash.php,v 1.23.10.13 2009/01/06 15:24:10 jan Exp $
+ * $Horde: imp/lib/Maintenance/Task/purge_trash.php,v 1.23.10.14 2012/02/06 05:53:39 slusarz Exp $
  *
  * Maintenance module that purges old messages in the Trash folder.
  *
@@ -76,7 +76,7 @@ class Maintenance_Task_purge_trash extends Maintenance_Task {
     function describeMaintenance()
     {
         return sprintf(_("All messages in your \"%s\" folder older than %s days will be permanently deleted."),
-                       IMP::displayFolder(IMP::folderPref($GLOBALS['prefs']->getValue('trash_folder'), true)),
+                       htmlspecialchars(IMP::displayFolder(IMP::folderPref($GLOBALS['prefs']->getValue('trash_folder'), true))),
                        $GLOBALS['prefs']->getValue('purge_trash_keep'));
     }
 
