@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: imp/message.php,v 2.560.4.62 2010-07-01 20:00:26 slusarz Exp $
+ * $Horde: imp/message.php,v 2.560.4.63 2012/02/06 05:53:37 slusarz Exp $
  *
  * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
@@ -492,7 +492,7 @@ if (!$printer_friendly) {
     $h_page_label = htmlspecialchars($page_label);
     $header_label = $h_page_label;
     if (isset($imp_search) && $imp_search->isSearchMbox()) {
-        $header_label .= ' [' . Horde::link(Util::addParameter(Horde::applicationUrl('mailbox.php'), 'mailbox', $mailbox_name)) . IMP::displayFolder($mailbox_name) . '</a>]';
+        $header_label .= ' [' . Horde::link(Util::addParameter(Horde::applicationUrl('mailbox.php'), 'mailbox', $mailbox_name)) . htmlspecialchars(IMP::displayFolder($mailbox_name)) . '</a>]';
     }
 
     /* Prepare the navbar top template. */
